<?php
/**
 * @package WordPress
 * @subpackage Theme Integrator
 *
 * @since 1.0
 *
 */



/**
 * Creates the cache files
 * 
 * @copyright Copyright (c), Ryan Hellyer
 * @author Ryan Hellyer <ryan@pixopoint.com>
 * @since 1.0
 */
class Theme_Integrator_Admin {

	/**
	 * Class constructor
	 * 
	 * Adds methods to appropriate hooks
	 * 
	 * @author Ryan Hellyer <ryan@pixopoint.com>
	 * @since 1.0
	 */
	public function __construct() {
		add_action( 'admin_init', array( $this, 'options_init' ) );
		add_action( 'admin_menu', array( $this, 'add_admin_page' ) );
	}

	/**
	 * Init plugin options to white list our options
	 * 
	 * @author Ryan Hellyer <ryan@pixopoint.com>
	 * @since 1.0
	 */
	public function options_init() {
		register_setting( 'theme_integrator', 'theme_integrator', array( $this, 'validate' ) );
	}

	/**
	 * Load up the menu page
	 * 
	 * @author Ryan Hellyer <ryan@pixopoint.com>
	 * @since 1.0
	 */
	public function add_admin_page() {
		add_options_page(
			__( 'Theme Integrator', 'theme-integrator' ),
			__( 'Theme Integrator', 'theme-integrator' ),
			'manage_options',
			'theme_integrator',
			 array( $this, 'do_admin_page' )
		);
		add_option( 'theme_integrator', false );
	}

	/**
	 * Create the options page
	 * 
	 * @author Ryan Hellyer <ryan@pixopoint.com>
	 * @since 1.0
	 */
   public function do_admin_page() {

		?>
		<div class="wrap">
			<?php screen_icon(); ?>
			<h2><?php _e( 'Theme Integrator', 'theme-integrator' ); ?></h2>

			<form method="post" action="options.php">
				<?php settings_fields( 'theme_integrator' ); ?>
				<table class="form-table"><?php

					/**
					 * Post/page ID selector
					 */
					?>
					<tr valign="top"><th scope="row"><?php _e( 'The post/page ID to grab the cached data from', 'sampletheme' ); ?></th>
						<td>
							<input id="theme_integrator" class="regular-text" type="text" name="theme_integrator" value="<?php esc_attr_e( get_option( 'theme_integrator' ) ); ?>" />
							<label class="description" for="theme_integrator"><?php _e( 'Page/post ID to use', 'theme-integrator' ); ?></label>
						</td>
					</tr>

				</table>

				<p class="submit">
					<input type="submit" class="button-primary" value="<?php _e( 'Save ID selection', 'theme-integrator' ); ?>" />
				</p>

				<h3><?php _e( 'Where to find the files ... ', 'theme-integrator' ); ?></h3>
				<p><?php
					_e( 'The HTML can be found in the following directory on your server ... ', 'theme-integrator' );

					$uploads_folder = wp_upload_dir();
					$upload_location = $uploads_folder['basedir'] . '/theme-integration';
					echo '<br /><strong>' . $upload_location . '</strong>';

					echo '<br /><br />';
					_e( 'Here are the locations of the current generated files ... ', 'theme-integrator' );
				?>
				<ul><?php
					// Display the path to the uploads folder
					$upload_url = $uploads_folder['baseurl'] . '/theme-integration';
					$counter = 0;
					while ( $counter <= 100 ) {
						if ( file_exists( $upload_location . '/chunk_' . $counter . '.html' ) ) {
							echo '<li><a href="' . $upload_url . '/chunk_' . $counter . '.html' . '">' . $upload_location . '/chunk_' . $counter . '.html</a></li>';
						}
					
						$counter++;
					}
					?></ul>
				</p>

				<h3><?php _e( 'Installation', 'theme-integrator' ); ?></h3>
				<p><?php
					_e( 'As seen in the code example below, call the function cache_chunk() in your theme to begin caching part of your site, then call it again to trigger the file to be saved.', 'theme-integrator' ); ?>
				</p>
				<p><?php
					_e( 'You can repeat this multiple times in your theme to cache various chunks, such as your header, widgets, sidebars etc.', 'theme-integrator' ); ?>
				</p>
				<code style="overflow:scroll;display: block;border:1px solid #ccc;width:100%;height:370px;"><?php require( THEME_INTEGRATION_DIR . 'inc/demo-code.txt' ); ?></code></pre>

			</form>
		</div><?php
	}

	/**
	 * Sanitize and validate input.
	 * 
	 * @author Ryan Hellyer <ryan@pixopoint.com>
	 * @since 1.0
	 * @param int $input
	 * @returns int $output
	 */
	public function validate( $input ) {
		$output = (int) $input;
		return $output;
	}

}
