<?php
/**
 * @package WordPress
 * @subpackage Theme Integrator
 *
 * @since 1.0
 *
 */


/**
 * Creates the cache files
 * 
 * @copyright Copyright (c), Ryan Hellyer
 * @author Ryan Hellyer <ryan@pixopoint.com>
 * @since 1.0
 */
class Theme_Integrator_Create_Cache {

	var $cache_chunk = 0;

	/**
	 * Processor for handling caching
	 * Buffers the output and sends data for storing
	 * 
	 * @since 1.0
	 * @author Ryan Hellyer <ryan@pixopoint.com>
	 */
	public function cache_chunk() {
		global $wp_query;

		// Only want to cache for logged out users
		if ( is_user_logged_in() )
			return;

		// Decided whether to cache or not
		if ( is_front_page() && 0 == get_option( 'theme_integrator' ) ) {
			$cache = true;
		}
		elseif ( $wp_query->post->ID == get_option( 'theme_integrator' ) ) {
			$cache = true;
		}

		// If not caching, then bail out now
		if ( empty( $cache ) )
			return;

		// Iterate the cache chunk by one on each iteration
		$this->cache_chunk = $this->cache_chunk + 1;

		// If cache chunk is odd, then is the first one, therefore time to start the buffer
		if ( $this->cache_chunk % 2) {
			$contents = '';
			ob_start();
		}
		// Else cache chunk is even, therefore is second one and need to grab buffer content and stash data to disk
		else {
			$contents = ob_get_contents();
			$this->store_chunk( $contents );
			ob_end_clean();
		}

		return $contents;
	}

	/**
	 * Store the chunk data in the file system
	 *
	 * @todo Use WP file API
	 * @since 1.0
	 * @author Ryan Hellyer <ryan@pixopoint.com>
	 */
	public function store_chunk( $contents ) {

		// Storing the file in the WP uploads folder
		$uploads_folder = wp_upload_dir();
		$upload_location = $uploads_folder['basedir'] . '/theme-integration';

		$chunk = ( $this->cache_chunk / 2 ); // Half the cache chunk will give the cache number (it's double since it gets iterated during both start and end of buffering)
		$location = $upload_location . '/chunk_' . $chunk . '.html'; // File location

		/*
		 * This is an attemp to use the file API, which went wrong because it doesn't seem to work on the front-end very well :()
		 * Code has been left here until I figure out how to fix it
		 *
		// Need to load admin functions for use with file API
		require( ABSPATH . '/wp-admin/includes/file.php' );
		require( ABSPATH . '/wp-admin/includes/screen.php' );

		$current_url = 'http://' . ( $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'] );
		$current_url = esc_url( $current_url );
		$current_location = str_replace( 'http://', '', $current_url );
 
		$url = wp_nonce_url( $current_location, 'theme_integrator' );
		$creds = request_filesystem_credentials( $url, '', false, false, array( 'theme_integrator' ) );

		// now we have some credentials, try to get the wp_filesystem running
		if ( ! WP_Filesystem( $creds ) ) {
			request_filesystem_credentials( $url, '', true, false, array( 'theme_integrator' ) );
		}

		// by this point, the $wp_filesystem global should be working, so let's use it to create a file
		global $wp_filesystem;
		$wp_filesystem->put_contents( $upload_location, $contents, FS_CHMOD_FILE );
*/

		// If the directory doesn't exist, make it ... note: this may not work on some servers. I should use WP HTTP API in future releases to fix this
		if ( !is_dir( $upload_location ) )
			mkdir( $upload_location, 0755 );

		// Finally, store the data chunk in a file
		file_put_contents( $location, $contents );

	}

}
